==> huaweicloudsdkcce-3.0.52-py2.py3-none-any.whl: huaweicloudsdkcce/v3/model/lvm_config.py <==
# coding: utf-8

import re
import six





class LVMConfig:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'lv_type': 'str',
        'path': 'str'
    }

    attribute_map = {
        'lv_type': 'lvType',
        'path': 'path'
    }

    def __init__(self, lv_type=None, path=None):
        """LVMConfig - a model defined in huaweicloud sdk"""
        
        

        self._lv_type = None
        self._path = None
        self.discriminator = None

        self.lv_type = lv_type
        if path is not None:
            self.path = path

    @property
    def lv_type(self):
        """Gets the lv_type of this LVMConfig.

        LVM写入模式：linear、striped。linear：线性模式；striped：条带模式，使用多块磁盘组成条带模式，能够提升磁盘性能。

        :return: The lv_type of this LVMConfig.
        :rtype: str
        """
        return self._lv_type

    @lv_type.setter
    def lv_type(self, lv_type):
        """Sets the lv_type of this LVMConfig.

        LVM写入模式：linear、striped。linear：线性模式；striped：条带模式，使用多块磁盘组成条带模式，能够提升磁盘性能。

        :param lv_type: The lv_type of this LVMConfig.
        :type: str
        """
        self._lv_type = lv_type

    @property
    def path(self):
        """Gets the path of this LVMConfig.

        磁盘挂载路径。仅在用户配置中生效。支持包含：数字、大小写字母、点、中划线、下划线的绝对路径。

        :return: The path of this LVMConfig.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this LVMConfig.

        磁盘挂载路径。仅在用户配置中生效。支持包含：数字、大小写字母、点、中划线、下划线的绝对路径。

        :param path: The path of this LVMConfig.
        :type: str
        """
        self._path = path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LVMConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcce-3.0.54-py2.py3-none-any.whl: huaweicloudsdkcce/v3/model/lvm_config.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class LVMConfig:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'lv_type': 'str',
        'path': 'str'
    }

    attribute_map = {
        'lv_type': 'lvType',
        'path': 'path'
    }

    def __init__(self, lv_type=None, path=None):
        """LVMConfig - a model defined in huaweicloud sdk"""
        
        

        self._lv_type = None
        self._path = None
        self.discriminator = None

        self.lv_type = lv_type
        if path is not None:
            self.path = path

    @property
    def lv_type(self):
        """Gets the lv_type of this LVMConfig.

        LVM写入模式：linear、striped。linear：线性模式；striped：条带模式，使用多块磁盘组成条带模式，能够提升磁盘性能。

        :return: The lv_type of this LVMConfig.
        :rtype: str
        """
        return self._lv_type

    @lv_type.setter
    def lv_type(self, lv_type):
        """Sets the lv_type of this LVMConfig.

        LVM写入模式：linear、striped。linear：线性模式；striped：条带模式，使用多块磁盘组成条带模式，能够提升磁盘性能。

        :param lv_type: The lv_type of this LVMConfig.
        :type: str
        """
        self._lv_type = lv_type

    @property
    def path(self):
        """Gets the path of this LVMConfig.

        磁盘挂载路径。仅在用户配置中生效。支持包含：数字、大小写字母、点、中划线、下划线的绝对路径。

        :return: The path of this LVMConfig.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this LVMConfig.

        磁盘挂载路径。仅在用户配置中生效。支持包含：数字、大小写字母、点、中划线、下划线的绝对路径。

        :param path: The path of this LVMConfig.
        :type: str
        """
        self._path = path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LVMConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
